﻿using FarPoint.Win.Spread;
using GrapeCity.Spreadsheet;
using GrapeCity.Spreadsheet.Drawing;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace CellHyperlinksCS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            // initialize fpSpread
            fpSpread1.AllowCellOverflow = true; // let cells overflow like Excel
            fpSpread1.Features.AutoCreateHyperlink = true; // automatically create hyperlinks with separate undo action
            fpSpread1.Features.EnhancedShapeEngine = true; // enable enhanced shapes
            fpSpread1.Features.ExcelCompatibleKeyboardShortcuts = true; // enable new Excel compatible keyboard shortcuts, allows Ctrl+K for Edit Hyperlink dialog
            // initialize worksheets
            fpSpread1.Sheets.Count = 2;
            fpSpread1.Sheets[0].SheetName = "Basic Usage";
            fpSpread1.Sheets[1].SheetName = "Formulas";
            InitializeBasicUsage();
            InitializeFormulas();
            splitContainer1.SplitterDistance = 21; // set split to minimum
        }

        private void InitializeBasicUsage()
        {
            IWorksheet ws = fpSpread1.AsWorkbook().Worksheets["Basic Usage"];
            IStyles styles = ws.Workbook.Styles; // workbook styles
            // create styles for cells
            IStyle titleStyle = styles.Add("title");
            titleStyle.IncludeFont = true;
            titleStyle.Font.Size = 14;
            titleStyle.Font.Bold = true;
            IStyle exampleTitleStyle = styles.Add("exampleTitle");
            exampleTitleStyle.Font.Bold = true;
            exampleTitleStyle.IncludeFont = true;
            // initialize cells
            ws.Cells[0, 0, ws.RowCount - 1, ws.ColumnCount - 1].Font.Name = "Calibri";
            ws.Cells[0, 0, ws.RowCount - 1, ws.ColumnCount - 1].Font.Size = 11;
            ws.Cells["B2"].Text = "Hyperlinks basic usage";
            ws.Cells["B2"].Style = styles["title"];
            ws.Cells["B4"].Text = "Cell Reference Link";
            ws.Cells["B4"].Style = styles["exampleTitle"];
            ws.Hyperlinks.Add("B5", "", "Formulas!C6", "click here to go to Formulas!C6\r\nClick and hold to select this cell.", "goto Formulas!C6");
            ws.Tables.Add("B4:B5", YesNoGuess.Yes);
            ws.Cells["D4"].Text = "Name Reference Link";
            ws.Cells["D4"].Style = styles["exampleTitle"];
            ws.Workbook.Names.Add("FormulaExample1", "Formulas!$C$6");
            ws.Hyperlinks.Add("D5", "", "FormulaExample1", "click here to go to FormulaExample1\r\nClick and hold to select this cell.", "goto FormulaExample1");
            ws.Tables.Add("D4:D5", YesNoGuess.Yes);
            ws.Cells["F4"].Text = "Table Reference Link";
            ws.Cells["F4"].Style = styles["exampleTitle"];
            ws.Hyperlinks.Add("F5", "", "Table1", "click here to go to Table1", "goto Table1");
            ws.Tables.Add("F4:F5", YesNoGuess.Yes);
            ws.Cells["B7"].Text = "Email Link";
            ws.Cells["B7"].Style = styles["exampleTitle"];
            ws.Hyperlinks.Add("B8", "mailto:spread.support@grapecity.com?subject=spread.support");//, "", "click here to mail for spread support\r\nClick and hold to select this cell.", "Spread support");
            ws.Tables.Add("B7:B8", YesNoGuess.Yes);
            ws.Cells["B10"].Text = "Web Link";
            ws.Cells["B10"].Style = styles["exampleTitle"];
            ws.Hyperlinks.Add("B11", "http://www.grapecity.com/", "", "click here to go to grapecity website\r\nClick and hold to select this cell.", "Grapecity website");
            ws.Tables.Add("B10:B11", YesNoGuess.Yes);
            ws.Cells["B13"].Text = "Shape Link";
            ws.Cells["B13"].Style = styles["exampleTitle"];
            IShape btn = ws.Shapes.AddShapeToCell(GrapeCity.Spreadsheet.Drawing.AutoShapeType.ReturnButton, 13, 1, ws.Columns[1].ColumnWidth, ws.Rows[13].RowHeight * 2);
            ws.Hyperlinks.Add(btn, "", "Formulas!C10", "click here to go to Formulas!C10\r\nRight-click to select this shape.");
            ws.Cells["B14:B15"].Merge();
            ws.Cells["D13"].Text = "Image Link";
            ws.Cells["D13"].Style = styles["exampleTitle"];
            IShape img = ws.Shapes.AddPictureToCell("Spread_Eagle_small.png", false, true, 13, 3, 60, 45);
            ws.Hyperlinks.Add(img, "", "Formulas!C14", "click here to go to Formulas!C14\r\nRight-click to select this iamge.");
            ws.Columns["A:F"].AutoFit();
            ws.Cells["A17"].Text = "Press Ctrl+K to open the Edit Hyperlink dialog to edit the link in the active cell or selected shape.";
            ws.Cells["A17"].Style = ws.Workbook.Styles.Add("note", "Note");
        }

        private void InitializeFormulas()
        {
            IWorksheet ws = fpSpread1.AsWorkbook().Worksheets["Formulas"];
            IStyles styles = ws.Workbook.Styles; // workbook styles
            // create styles for cells
            IStyle titleStyle = styles["title"];
            IStyle exampleTitleStyle = styles["exampleTitle"];
            IStyle formulaLabelStyle = styles.Add("formulaLabel");
            formulaLabelStyle.Interior.Color = GrapeCity.Spreadsheet.Color.FromArgb(255, 242, 204);
            formulaLabelStyle.IncludePatterns = true;
            IStyle resultLabelStyle = styles.Add("resultLabel");
            resultLabelStyle.Interior.Color = GrapeCity.Spreadsheet.Color.FromArgb(226, 240, 217);
            resultLabelStyle.IncludePatterns = true;
            IStyle formulaExampleStyle = styles.Add("formulaExample");
            formulaExampleStyle.Font.Color = GrapeCity.Spreadsheet.Color.FromArgb(192, 0, 0);
            formulaExampleStyle.IncludePatterns = true;
            // initialize cells
            ws.Cells[0, 0, ws.RowCount - 1, ws.ColumnCount - 1].Font.Name = "Calibri";
            ws.Cells[0, 0, ws.RowCount - 1, ws.ColumnCount - 1].Font.Size = 11;
            ws.Cells["B2"].Text = "HYPERLINK function usage";
            ws.Cells["B2"].Style = titleStyle;
            ws.Cells["B4"].Text = "Cell Reference Link";
            ws.Cells["B4"].Style = exampleTitleStyle;
            ws.Cells["B5"].Text = "Formula";
            ws.Cells["B5"].Style = formulaLabelStyle;
            ws.Cells["C5"].Formula = "FORMULATEXT(C6)";
            ws.Cells["C5"].Style = formulaExampleStyle;
            ws.Cells["B6"].Text = "Result";
            ws.Cells["B6"].Style = resultLabelStyle;
            ws.Cells["C6"].Formula = "HYPERLINK(\"#'Basic Usage'!B5\",\"goto Basic Usage!B5\")";
            ws.Cells["B8"].Text = "Name Reference Link";
            ws.Cells["B8"].Style = exampleTitleStyle;
            ws.Cells["B9"].Text = "Formula";
            ws.Cells["B9"].Style = formulaLabelStyle;
            ws.Cells["C9"].Formula = "FORMULATEXT(C10)";
            ws.Cells["C9"].Style = formulaExampleStyle;
            ws.Cells["B10"].Text = "Result";
            ws.Cells["B10"].Style = resultLabelStyle;
            ws.Cells["C10"].Formula = "HYPERLINK(\"#FormulaExample1\",\"goto FormulaExample1\")";
            ws.Cells["B12"].Text = "Table Reference Link";
            ws.Cells["B12"].Style = exampleTitleStyle;
            ws.Cells["B13"].Text = "Formula";
            ws.Cells["B13"].Style = formulaLabelStyle;
            ws.Cells["C13"].Formula = "FORMULATEXT(C14)";
            ws.Cells["C13"].Style = formulaExampleStyle;
            ws.Cells["B14"].Text = "Result";
            ws.Cells["B14"].Style = resultLabelStyle;
            ws.Cells["C14"].Formula = "HYPERLINK(\"#Table3\",\"goto Table3\")";
            ws.Cells["B16"].Text = "Email Link";
            ws.Cells["B16"].Style = exampleTitleStyle;
            ws.Cells["B17"].Text = "Formula";
            ws.Cells["B17"].Style = formulaLabelStyle;
            ws.Cells["C17"].Formula = "FORMULATEXT(C18)";
            ws.Cells["C17"].Style = formulaExampleStyle;
            ws.Cells["B18"].Text = "Result";
            ws.Cells["B18"].Style = resultLabelStyle;
            ws.Cells["C18"].Formula = "HYPERLINK(\"mailto:spread.support@grapecity.com?subject=spread.support\",\"Spread support\")";
            ws.Cells["B20"].Text = "Web Link";
            ws.Cells["B20"].Style = exampleTitleStyle;
            ws.Cells["B21"].Text = "Formula";
            ws.Cells["B21"].Style = formulaLabelStyle;
            ws.Cells["C21"].Formula = "FORMULATEXT(C22)";
            ws.Cells["C21"].Style = formulaExampleStyle;
            ws.Cells["B22"].Text = "Result";
            ws.Cells["B22"].Style = resultLabelStyle;
            ws.Cells["C22"].Formula = "HYPERLINK(\"http://www.grapecity.com/\",\"Grapecity website\")";
            ws.Columns["A:A"].AutoFit();
        }
        private void insertHyperlinkToolStripMenuItem_Click(object sender, EventArgs e)
        {
            HyperlinkForm form = new HyperlinkForm(fpSpread1.AsWorkbook().ActiveSheet);
            form.ShowDialog();
        }
    }
}
